#
# spec file for package ghc-blaze-builder
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name blaze-builder
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.3
Release:        1.2
Summary:        Efficient buffered output
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
BuildRequires:  ghc-test-framework-hunit-prof
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
%endif

%description
This library allows to efficiently serialize Haskell values to lazy bytestrings
with a large average chunk size. The large average chunk size allows to make
good use of cache prefetching in later processing steps (e.g.
compression) and reduces the system call overhead when writing the resulting
lazy bytestring to a file or sending it over the network.

This library was inspired by the module Data.Binary.Builder provided by the
binary package. It was originally developed with the specific needs of the
blaze-html package in mind. Since then it has been restructured to serve as a
drop-in replacement for Data.Binary.Builder, which it improves upon both in
speed as well as expressivity.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES README.markdown TODO

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu May 15 2025 Peter Simons <psimons@suse.com>
- Update blaze-builder to version 0.4.3.
  * 0.4.3 2025-05-15
  - Fix computation of max buffer overhead on 32 bit platforms
    (sternenseemann, PR #8 https://github.com/blaze-builder/blaze-builder/pull/8)
  - Drop support for GHC 7, bytestring < 0.10.4 and text < 1.1.2
  - Tested with GHC 8.0 - 9.12.2
* Sun Aug 27 2023 Peter Simons <psimons@suse.com>
- Update blaze-builder to version 0.4.2.3.
  * 0.4.2.3 2023-08-27
  - Fix compilation warnings concerning non-canonical mappend
  - Support bytestring-0.12
  - Support text-2.1
  - Tested with GHC 7.0.4 to 9.8.1 alpha3
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Dec 26 2021 Peter Simons <psimons@suse.com>
- Update blaze-builder to version 0.4.2.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Oct 19 2021 psimons@suse.com
- Update blaze-builder to version 0.4.2.2.
  * 0.4.2.2
  - Support GHC 9.2
* Wed Jan 20 2021 psimons@suse.com
- Update blaze-builder to version 0.4.2.1.
  * 0.4.2.1
  - Bump cabal file to Cabal >= 1.10
  * 0.4.2.0
  - Make semigroup instances unconditional
  - Support bytestring-0.11
  - Support semigroups-0.19
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Sep 22 2020 psimons@suse.com
- Update blaze-builder to version 0.4.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update blaze-builder to version 0.4.1.0.
  - Gain compatibility with the Semigroup/Monoid proposal
  - Add Word8 HTML escaping builders
  - Speed up `fromHtmlEscapedText` and `fromHtmlEscapedLazyText`
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.0.2 revision 0 with cabal2obs.
* Tue Apr 19 2016 mimi.vx@gmail.com
- update to 0.4.0.2
- remove useless _service
  * Fixed warnings on GHC 7.10
* Fri Apr 17 2015 mimi.vx@gmail.com
- update to 0.4.0.1
  * See upstream CHANGES and blog:
  <http://blog.melding-monads.com/2015/02/12/announcing-blaze-builder-0-4/>
* Wed Sep 24 2014 peter.trommler@ohm-hochschule.de
- update to 0.3.3.4
  * compatibility with Haskell Platform 2014.2.0.0 (ghc-text)
* Mon May 13 2013 peter.trommler@ohm-hochschule.de
- update to 0.3.1.1 from upstream
  * all warnings fixed
  * ghc7.8 compatible
* Tue Jun  5 2012 peter.trommler@ohm-hochschule.de
- cabal2spec 0.25.5 template for spec file
* Fri Mar 16 2012 peter.trommler@ohm-hochschule.de
- added BuildRoot for SLE_11_SP1/2
* Fri Mar  2 2012 peter.trommler@ohm-hochschule.de
- initial packaging
